summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLubosz Sarnecki <lubosz@gmail.com>2013-11-13 13:18:00 +0100
committerThibault Saunier <thibault.saunier@collabora.com>2013-11-22 17:50:27 -0300
commit7b1df27c869e15f068ad561b482a3c670fb19d7e (patch)
tree33c677b5a96d8ad57fb4324c5f4d4966417d9698
parenta73644a7b941b8fa270824ef7bd9d40d60cafd10 (diff)
gir: fix warnings
-rw-r--r--ges/Makefile.am8
-rw-r--r--ges/ges-gerror.h6
-rw-r--r--ges/ges-timeline.c2
-rw-r--r--ges/ges-track-element.c4
-rw-r--r--ges/ges-uri-asset.c10
-rw-r--r--ges/ges-utils.c4
-rw-r--r--ges/ges-utils.h4
7 files changed, 20 insertions, 18 deletions
diff --git a/ges/Makefile.am b/ges/Makefile.am
index 30728d8b..5ded057a 100644
--- a/ges/Makefile.am
+++ b/ges/Makefile.am
@@ -130,12 +130,12 @@ libges_@GST_API_VERSION@include_HEADERS = \
ges-smart-adder.h \
ges-smart-video-mixer.h \
ges-utils.h \
- ges-group.h \
- gstframepositionner.h
+ ges-group.h
noinst_HEADERS = \
ges-internal.h \
- ges-auto-transition.h
+ ges-auto-transition.h \
+ gstframepositionner.h
libges_@GST_API_VERSION@_la_CFLAGS = -I$(top_srcdir) $(GST_PBUTILS_CFLAGS) \
$(GST_VIDEO_CFLAGS) $(GST_CONTROLLER_CFLAGS) $(GST_PLUGINS_BASE_CFLAGS) \
@@ -189,6 +189,7 @@ GES-@GST_API_VERSION@.gir: $(INTROSPECTION_SCANNER) libges-@GST_API_VERSION@.la
--libtool="$(top_builddir)/libtool" \
--pkg gstreamer-@GST_API_VERSION@ \
--pkg gstreamer-pbutils-@GST_API_VERSION@ \
+ --pkg gstreamer-controller-@GST_API_VERSION@ \
--pkg gio-2.0 \
--pkg-export ges-@GST_API_VERSION@ \
--add-init-section="gst_init(NULL, NULL);" \
@@ -218,6 +219,7 @@ typelibs_DATA = $(BUILT_GIRSOURCES:.gir=.typelib)
--includedir=`$(PKG_CONFIG) --variable=girdir gstreamer-video-@GST_API_VERSION@` \
--includedir=`$(PKG_CONFIG) --variable=girdir gstreamer-tag-@GST_API_VERSION@` \
--includedir=`$(PKG_CONFIG) --variable=girdir gstreamer-base-@GST_API_VERSION@` \
+ --includedir=`$(PKG_CONFIG) --variable=girdir gstreamer-controller-@GST_API_VERSION@` \
--includedir=`$(PKG_CONFIG) --variable=girdir gio-2.0` \
$(INTROSPECTION_COMPILER_OPTS) $< -o $(@F)
diff --git a/ges/ges-gerror.h b/ges/ges-gerror.h
index b35f2a4e..8391d5e9 100644
--- a/ges/ges-gerror.h
+++ b/ges/ges-gerror.h
@@ -17,14 +17,14 @@
* Boston, MA 02110-1301, USA.
*/
+#ifndef __GES_ERROR_H__
+#define __GES_ERROR_H__
+
/**
* SECTION: ges-gerror
* @short_description: GError — Categorized error messages
*/
-#ifndef __GES_ERROR_H__
-#define __GES_ERROR_H__
-
G_BEGIN_DECLS
/**
diff --git a/ges/ges-timeline.c b/ges/ges-timeline.c
index e620f859..1edfd2f0 100644
--- a/ges/ges-timeline.c
+++ b/ges/ges-timeline.c
@@ -521,7 +521,7 @@ ges_timeline_class_init (GESTimelineClass * klass)
G_TYPE_PTR_ARRAY, 2, GES_TYPE_CLIP, GES_TYPE_TRACK_ELEMENT);
/**
- * GESTimeline::commited
+ * GESTimeline::commited:
* @timeline: the #GESTimeline
*/
ges_timeline_signals[COMMITED] =
diff --git a/ges/ges-track-element.c b/ges/ges-track-element.c
index cf052e67..e1060caa 100644
--- a/ges/ges-track-element.c
+++ b/ges/ges-track-element.c
@@ -279,7 +279,7 @@ ges_track_element_init (GESTrackElement * self)
priv->bindings_hashtable = g_hash_table_new_full (g_str_hash, g_str_equal,
g_free, NULL);
priv->children_props =
- g_hash_table_new_full ((GHashFunc) pspec_hash, pspec_equal,
+ g_hash_table_new_full ((GHashFunc) ges_pspec_hash, ges_pspec_equal,
(GDestroyNotify) g_param_spec_unref, gst_object_unref);
}
@@ -733,7 +733,7 @@ strv_find_str (const gchar ** strv, const char *str)
* take into account (as defined in the factory meta "klass" field)
* @blacklist: (array zero-terminated=1) (transfer none) (allow-none): A
* blacklist of elements factory names to not take into account
- * @witelist: (array zero-terminated=1) (transfer none) (allow-none): A list
+ * @whitelist: (array zero-terminated=1) (transfer none) (allow-none): A list
* of propery names to add as children properties
*
* Looks for the properties defines with the various parametters and add
diff --git a/ges/ges-utils.c b/ges/ges-utils.c
index 769952db..487dd6c8 100644
--- a/ges/ges-utils.c
+++ b/ges/ges-utils.c
@@ -101,7 +101,7 @@ element_end_compare (GESTimelineElement * a, GESTimelineElement * b)
}
gboolean
-pspec_equal (gconstpointer key_spec_1, gconstpointer key_spec_2)
+ges_pspec_equal (gconstpointer key_spec_1, gconstpointer key_spec_2)
{
const GParamSpec *key1 = key_spec_1;
const GParamSpec *key2 = key_spec_2;
@@ -111,7 +111,7 @@ pspec_equal (gconstpointer key_spec_1, gconstpointer key_spec_2)
}
guint
-pspec_hash (gconstpointer key_spec)
+ges_pspec_hash (gconstpointer key_spec)
{
const GParamSpec *key = key_spec;
const gchar *p;
diff --git a/ges/ges-utils.h b/ges/ges-utils.h
index ca09127c..59c1f9d8 100644
--- a/ges/ges-utils.h
+++ b/ges/ges-utils.h
@@ -27,8 +27,8 @@
G_BEGIN_DECLS
GESTimeline * ges_timeline_new_audio_video (void);
-gboolean pspec_equal (gconstpointer key_spec_1, gconstpointer key_spec_2);
-guint pspec_hash (gconstpointer key_spec);
+gboolean ges_pspec_equal (gconstpointer key_spec_1, gconstpointer key_spec_2);
+guint ges_pspec_hash (gconstpointer key_spec);
G_END_DECLS
diff --git a/ges/ges-uri-asset.c b/ges/ges-uri-asset.c
index 78373326..40c42701 100644
--- a/ges/ges-uri-asset.c
+++ b/ges/ges-uri-asset.c
@@ -487,19 +487,19 @@ ges_uri_clip_asset_request_sync (const gchar * uri, GError ** error)
/**
* ges_uri_clip_asset_class_set_timeout:
* @class: The #GESUriClipAssetClass on which to set the discoverer timeout
* @timeout: The timeout to set
*
* Sets the timeout of #GESUriClipAsset loading
*/
void
-ges_uri_clip_asset_class_set_timeout (GESUriClipAssetClass * class,
+ges_uri_clip_asset_class_set_timeout (GESUriClipAssetClass * klass,
GstClockTime timeout)
{
- g_return_if_fail (GES_IS_URI_CLIP_ASSET_CLASS (class));
+ g_return_if_fail (GES_IS_URI_CLIP_ASSET_CLASS (klass));
- g_object_set (class->discoverer, "timeout", timeout, NULL);
- g_object_set (class->sync_discoverer, "timeout", timeout, NULL);
+ g_object_set (klass->discoverer, "timeout", timeout, NULL);
+ g_object_set (klass->sync_discoverer, "timeout", timeout, NULL);
}
/**
@@ -487,19 +487,19 @@ ges_uri_clip_asset_request_sync (const gchar * uri, GError ** error)
/**
* ges_uri_clip_asset_class_set_timeout:
- * @class: The #GESUriClipAssetClass on which to set the discoverer timeout
+ * @klass: The #GESUriClipAssetClass on which to set the discoverer timeout
* @timeout: The timeout to set
*